@@ -34,7 +34,7 @@ import math
 from urllib.request import urlretrieve
 from importlib import util
 
-program_version = "1.1.8"
+program_version = "1.1.9"
 eth_addr = "0x81F7B979fEa6134bA9FD5c701b3501A2e61E897a"
 btc_addr = "3CPmacGm34qYvR6XWLVEJmi2aNe3PZqUuq"
 
@@ -43,7 +43,7 @@ rnode_serial = None
 rnode_port = None
 rnode_baudrate = 115200
 known_keys = [["unsigned.io", "30819f300d06092a864886f70d010101050003818d0030818902818100bf831ebd99f43b477caf1a094bec829389da40653e8f1f83fc14bf1b98a3e1cc70e759c213a43f71e5a47eb56a9ca487f241335b3e6ff7cdde0ee0a1c75c698574aeba0485726b6a9dfc046b4188e3520271ee8555a8f405cf21f81f2575771d0b0887adea5dd53c1f594f72c66b5f14904ffc2e72206a6698a490d51ba1105b0203010001"], ["unsigned.io", "30819f300d06092a864886f70d010101050003818d0030818902818100e5d46084e445595376bf7efd9c6ccf19d39abbc59afdb763207e4ff68b8d00ebffb63847aa2fe6dd10783d3ea63b55ac66f71ad885c20e223709f0d51ed5c6c0d0b093be9e1d165bb8a483a548b67a3f7a1e4580f50e75b306593fa6067ae259d3e297717bd7ff8c8f5b07f2bed89929a9a0321026cf3699524db98e2d18fb2d020300ff39"]]
-firmware_update_url = "https://github.com/markqvist/RNode_Firmware/raw/master/Precompiled/"
+firmware_update_url = "https://github.com/markqvist/RNode_Firmware/raw/master/Release/"
 fw_filename = None
 mapped_model = None
 
@@ -750,6 +750,19 @@ class RNode():
         else:
             raise IOError("Got invalid response while detecting device")
 
+firmware_version_url = "https://unsigned.io/firmware/latest/?variant="
+def download_firmware(fw_filename):
+    try:
+        urlretrieve(firmware_update_url+fw_filename, "update/"+fw_filename)
+        try:
+            urlretrieve(firmware_version_url+fw_filename, "update/"+fw_filename+".version")
+        except Exception as e:
+            pass
+    except Exception as e:
+        RNS.log("Could not download required firmware file. The contained exception was:")
+        RNS.log(str(e))
+        exit()
+
 def rnode_open_serial(port):
     import serial
     return serial.Serial(
@@ -1188,7 +1201,7 @@ def main():
             try:
                 RNS.log("Downloading latest frimware from GitHub...")
                 os.makedirs("./update", exist_ok=True)
-                urlretrieve(firmware_update_url+fw_filename, "update/"+fw_filename)
+                download_firmware(fw_filename)
                 RNS.log("Firmware download completed")
             except Exception as e:
                 RNS.log("Could not download firmware package")
@@ -1509,7 +1522,7 @@ def main():
                     try:
                         RNS.log("Downloading latest firmware from GitHub...")
                         os.makedirs("./update", exist_ok=True)
-                        urlretrieve(firmware_update_url+fw_filename, "update/"+fw_filename)
+                        download_firmware(fw_filename)
                         RNS.log("Firmware download completed")
                         if fw_filename.endswith(".zip"):
                             RNS.log("Extracting firmware...")
